import { request } from 'umi';
import { getDataBaseUrl,getStoremanagement } from '@/global_data';


export async function GetAllStore() {
  return request(getStoremanagement()+'/api/shop/alllist', {
    method: 'GET'
  });
}

/** 获取  */
export async function Getstorestaffpage(data) {
     return request(getStoremanagement()+`/api/StoreStaff/GetStoreStaffPage`, {
      method: 'POST',
      data: data,
    });
  }

  /** 新增  */
export async function Addstorestaff(data) {
    return request(getStoremanagement()+`/api/StoreStaff/AddStoreStaff`, {
     method: 'POST',
     data: data,
   });
 }

   /** 修改  */
export async function Updatestorestaff(data) {
    return request(getStoremanagement()+`/api/StoreStaff/UpdateStoreStaff`, {
     method: 'put',
     data: data,
     // params: { ...params },
     // ...(options || {}),
   });
 }
 

   /** 删除  */
export async function Delstorestaff(data) {
    return request(getStoremanagement()+`​/api/StoreStaff/DelStoreStaff`, {
     method: 'DELETE',
     data: data,
     // params: { ...params },

     // ...(options || {}),
   });
 }


    /** 修改  */
export async function UpdatestorestaffPwd(data) {
  return request(getStoremanagement()+`/api/StoreStaff/UpdateStoreStaffPwd`, {
   method: 'put',
   data: data,
   // params: { ...params },
   // ...(options || {}),
 });
}